@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020 by Vd.
+# Copyright (C) 2015-2021 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -199,4 +199,4 @@ from .voice_chat_started import VoiceChatStarted
 from .webhook_info import WebhookInfo
 
 API_URL = "https://api.telegram.org/bot%s/"
-API_FILE_URL = "https://api.telegram.org/file/bot%s/"
+API_FILE_URL = "https://api.telegram.org/file/bot%s/%s"
