@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020 by Vd.
+# Copyright (C) 2015-2021 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -7,9 +7,9 @@ import asyncio
 import logging
 import signal
 from contextlib import suppress
-from typing import TYPE_CHECKING, Callable, Union, List
+from typing import TYPE_CHECKING, Callable, Union, List, Optional
 
-from ..api import Request
+from ..api import Request, UpdateType
 
 if TYPE_CHECKING:
     from ..bot import Bot
@@ -29,7 +29,8 @@ class Executor:
     def can_process_webhook_request(self, request: Request) -> bool:
         return False
 
-    async def add_bot(self, bot: 'Bot', *, drop_pending_updates=False):
+    async def add_bot(self, bot: 'Bot', *, allowed_updates: Optional[List[UpdateType]] = None,
+                      drop_pending_updates: bool = False, **kwargs):
         raise NotImplementedError
 
     async def remove_bot(self, bot: 'Bot'):
@@ -43,15 +44,7 @@ class Executor:
 
     @staticmethod
     def _run(executor: 'Executor', add: Callable, remove: Callable, bots: Union['Bot', List['Bot']],
-             signals: tuple = (signal.SIGINT, signal.SIGTERM), shutdown_wait=10):
-        """
-
-        :param bots:
-        :param add:
-        :param remove:
-        :param signals:
-        :param shutdown_wait:
-        """
+             signals: tuple = (signal.SIGINT, signal.SIGTERM), shutdown_wait: int = 10):
 
         loop = asyncio.get_event_loop()
 
